==> owncloud-10.0.8.tar.bz2: owncloud/apps/files_sharing/l10n/nb_NO.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server til server-deling er ikke aktivert på denne serveren",
    "The mountpoint name contains invalid characters." : "Navnet på oppkoblingspunktet inneholder ugyldige tegn.",
    "Not allowed to create a federated share with the same user server" : "Ikke tillatt å opprette en forent deling med den samme bruker-serveren",
    "Invalid or untrusted SSL certificate" : "Ugyldig eller ikke-klarert SSL-sertifikat",
    "Could not authenticate to remote share, password might be wrong" : "Klarte ikke å autentisere mot ekstern deling. Passordet kan være feil",
    "Storage not valid" : "Lagerplass ikke gyldig",
    "Couldn't add remote share" : "Klarte ikke å legge til ekstern deling",
    "Shared with you" : "Delt med deg",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt med lenke",
    "Uploading..." : "Laster opp...",
    "Nothing shared with you yet" : "Ingenting er delt med deg ennå",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you share will show up here" : "Filer og mapper som du deler vil bli vist her",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenke vil bli vist her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du å legge til ekstern deling {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern deling",
    "Remote share password" : "Passord for ekstern deling",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til ekstern deling",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen ownCloud-installasjon (7 eller høyere) funnet på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-url",
    "Share" : "Delt ressurs",
    "No expiration date set" : "Utløpsdato ikke satt",
    "Shared by" : "Delt av",
    "Sharing" : "Deling",
    "Share API is disabled" : "Delings-API er deaktivert",
    "Wrong share ID, share doesn't exist" : "Feil delings-ID, delingen finnes ikke",
    "Could not delete share" : "Klarte ikke å slette deling",
    "Please specify a file or folder path" : "Vennligst angi sti til en fil eller mappe",
    "Wrong path, file/folder doesn't exist" : "Feil sti, fil/mappe finnest ikke",
    "Please specify a valid user" : "Vennligst angi en gyldig bruker",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktivert av administratoren",
    "Please specify a valid group" : "Vennligst angi en gyldig gruppe",
    "Public link sharing is disabled by the administrator" : "Deling med offentlig lenke er deaktivert av administratoren",
    "Public upload disabled by the administrator" : "Deling med offentlig opplasting er deaktivert av administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentlig opplasting er kun mulig for offentlig delte mapper",
    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato, datoformatet må være ÅÅÅÅ-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Deling av %s feilet, fordi serveren ikke tillater delinger fra type %s",
    "Unknown share type" : "Ukjent delingstype",
    "Not a directory" : "Ikke en katalog",
    "Could not lock path" : "Klarte ikke å låse stien",
    "Can't change permissions for public share links" : "Kan ikke endre rettigheter for offentlig delte lenker",
    "Wrong or no update parameter given" : "Feil eller ingen oppdateringsparameter angitt",
    "Cannot increase permissions" : "Kan ikke øke tillatelser",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentlig delt fil eller mappe ble <strong>lastet ned</strong>",
    "You received a new remote share %2$s from %1$s" : "Du mottok en ny ekstern deling %2$s fra %1$s",
    "You received a new remote share from %s" : "Du mottok en ny ekstern deling fra %s",
    "%1$s accepted remote share %2$s" : "%1$s aksepterte ekstern deling %2$s",
    "%1$s declined remote share %2$s" : "%1$s avviste ekstern deling %2$s",
    "%1$s unshared %2$s from you" : "%1$s fjernet deling %2$s fra deg",
    "Public shared folder %1$s was downloaded" : "Offentlig delt mappe %1$s ble lastet ned",
    "Public shared file %1$s was downloaded" : "Offentlig delt fil %1$s ble lastet ned",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delte %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du fjernet deling av %2$s for %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s fjernet deling av %3$s for %1$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppe %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delte %1$s med gruppe %3$s",
    "You removed the share of group %2$s for %1$s" : "Du fjernet deling av gruppe %2$s for %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s fjernet deling av gruppe %3$s for %1$s",
    "%2$s shared %1$s via link" : "%2$s delte %1$s via lenke",
    "You shared %1$s via link" : "Du delte %1$s via lenke",
    "You removed the public link for %1$s" : "Du fjernet den offentlige lenken for %1$s",
    "%2$s removed the public link for %1$s" : "%2$s fjernet den offentlige lenken for %1$s",
    "Your public link for %1$s expired" : "Din offentlige lenke for %1$s er utløpt",
    "The public link of %2$s for %1$s expired" : "Den offentlige lenken til %2$s for %1$s er utløpt",
    "%2$s shared %1$s with you" : "%2$s delte %1$s med deg",
    "%2$s removed the share for %1$s" : "%2$s fjernet delingen for %1$s",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Shared with %2$s" : "Delt med %2$s",
    "Shared with %3$s by %2$s" : "Delt med %3$s av %2$s",
    "Removed share for %2$s" : "Fjernet deling for %2$s",
    "%2$s removed share for %3$s" : "%2$s fjernet deling for %3$s",
    "Shared with group %2$s" : "Delt med gruppe %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppe %3$s av %2$s",
    "Removed share of group %2$s" : "Fjernet deling av gruppe %2$s",
    "%2$s removed share of group %3$s" : "%2$s fjernet deling av gruppe %3$s",
    "Shared via link by %2$s" : "Delt via lenke av %2$s",
    "Shared via public link" : "Delt via offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "%2$s removed public link" : "%2$s fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "Public link of %2$s expired" : "Offentlig lenke til %2$s er utløpt",
    "Shared by %2$s" : "Delt av %2$s",
    "Shares" : "Delinger",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Password" : "Passord",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "Share time" : "Delingstidspunkt",
    "Expiration date" : "Utløpsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "Reasons might be:" : "Mulige årsaker:",
    "the item was removed" : "elementet er fjernet",
    "the link expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er deaktivert",
    "For more info, please ask the person who sent this link." : "For mer informasjon, spør personen som sendte lenken.",
    "%s is publicly shared" : "%s er offentlig delt",
    "Add to your ownCloud" : "Legg til i din ownCloud",
    "Download" : "Last ned",
    "Download %s" : "Last ned %s",
    "Direct link" : "Direkte lenke",
    "Anonymous upload" : "Anonym opplasting",
    "Uploaded files" : "Opplastede filer",
    "Click to select files or use drag & drop to upload" : "Klikk for å velge eller dra filer hit for å laste opp",
    "Cannot remove all permissions" : "Kan ikke fjerne alle tilganger",
    "No permission to create share" : "Ingen tillatelse til å opprette deling"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.7.0.tar.bz2: owncloud/apps/files_sharing/l10n/nb_NO.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server til server-deling er ikke aktivert på denne serveren",
    "The mountpoint name contains invalid characters." : "Navnet på oppkoblingspunktet inneholder ugyldige tegn.",
    "Not allowed to create a federated share with the same user server" : "Ikke tillatt å opprette en forent deling med den samme bruker-serveren",
    "Could not authenticate to remote share, password might be wrong" : "Klarte ikke å autentisere mot ekstern deling. Passordet kan være feil",
    "Storage not valid" : "Lagerplass ikke gyldig",
    "Couldn't add remote share" : "Klarte ikke å legge til ekstern deling",
    "Shared with you" : "Delt med deg",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt med lenke",
    "Anonymous upload" : "Anonym opplasting",
    "Click to select files or use drag & drop to upload" : "Klikk for å velge eller dra filer hit for å laste opp",
    "Uploaded files" : "Opplastede filer",
    "Uploading..." : "Laster opp...",
    "Nothing shared with you yet" : "Ingenting er delt med deg ennå",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg vil bli vist her",
    "Nothing shared yet" : "Ingenting er delt ennå",
    "Files and folders you share will show up here" : "Filer og mapper som du deler vil bli vist her",
    "No shared links" : "Ingen delte lenker",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenke vil bli vist her",
    "An error occurred while updating share state: {message}" : "Det oppstod en feil ved oppdatering av delingen: {message}",
    "Accept Share" : "Aksepter Deling",
    "Decline Share" : "Avslå Deling",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du å legge til ekstern deling {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern deling",
    "Remote share password" : "Passord for ekstern deling",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til ekstern deling",
    "You can upload into this folder" : "Du kan laste opp til denne mappen",
    "No ownCloud installation (7 or higher) found at {remote}" : "Ingen ownCloud-installasjon (7 eller høyere) funnet på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud url",
    "Share" : "Delt ressurs",
    "No expiration date set" : "Utløpsdato ikke satt",
    "Declined" : "Avvist",
    "Pending" : "Venter",
    "Shared by" : "Delt av",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe ble <strong>delt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe ble delt fra <strong>en annen server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentlig delt fil eller mappe ble <strong>lastet ned</strong>",
    "You received a new remote share %2$s from %1$s" : "Du mottok en ny ekstern deling %2$s fra %1$s",
    "You received a new remote share from %s" : "Du mottok en ny ekstern deling fra %s",
    "%1$s accepted remote share %2$s" : "%1$s aksepterte ekstern deling %2$s",
    "%1$s declined remote share %2$s" : "%1$s avviste ekstern deling %2$s",
    "%1$s unshared %2$s from you" : "%1$s fjernet deling %2$s fra deg",
    "Public shared folder %1$s was downloaded" : "Offentlig delt mappe %1$s ble lastet ned",
    "Public shared file %1$s was downloaded" : "Offentlig delt fil %1$s ble lastet ned",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delte %1$s med %3$s",
    "You removed the share of %2$s for %1$s" : "Du fjernet deling av %2$s for %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s fjernet deling av %3$s for %1$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppe %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delte %1$s med gruppe %3$s",
    "You removed the share of group %2$s for %1$s" : "Du fjernet deling av gruppe %2$s for %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s fjernet deling av gruppe %3$s for %1$s",
    "%2$s shared %1$s via link" : "%2$s delte %1$s via lenke",
    "You shared %1$s via link" : "Du delte %1$s via lenke",
    "You removed the public link for %1$s" : "Du fjernet den offentlige lenken for %1$s",
    "%2$s removed the public link for %1$s" : "%2$s fjernet den offentlige lenken for %1$s",
    "Your public link for %1$s expired" : "Din offentlige lenke for %1$s er utløpt",
    "The public link of %2$s for %1$s expired" : "Den offentlige lenken til %2$s for %1$s er utløpt",
    "%2$s shared %1$s with you" : "%2$s delte %1$s med deg",
    "%2$s removed the share for %1$s" : "%2$s fjernet delingen for %1$s",
    "Downloaded via public link" : "Nedlastet via offentlig lenke",
    "Shared with %2$s" : "Delt med %2$s",
    "Shared with %3$s by %2$s" : "Delt med %3$s av %2$s",
    "Removed share for %2$s" : "Fjernet deling for %2$s",
    "%2$s removed share for %3$s" : "%2$s fjernet deling for %3$s",
    "Shared with group %2$s" : "Delt med gruppe %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppe %3$s av %2$s",
    "Removed share of group %2$s" : "Fjernet deling av gruppe %2$s",
    "%2$s removed share of group %3$s" : "%2$s fjernet deling av gruppe %3$s",
    "Shared via link by %2$s" : "Delt via lenke av %2$s",
    "Shared via public link" : "Delt via offentlig lenke",
    "Removed public link" : "Fjernet offentlig lenke",
    "%2$s removed public link" : "%2$s fjernet offentlig lenke",
    "Public link expired" : "Offentlig lenke er utløpt",
    "Public link of %2$s expired" : "Offentlig lenke til %2$s er utløpt",
    "Shared by %2$s" : "Delt av %2$s",
    "Shares" : "Delinger",
    "File sharing" : "Fildeling",
    "Public link" : "Offentlig lenke",
    "Couldn't send mail to following recipient(s): %s " : "Kunne ikke sende e-post til følgende mottaker (e): %s",
    "Share API is disabled" : "Delings-API er deaktivert",
    "Wrong share ID, share doesn't exist" : "Feil delings-ID, delingen finnes ikke",
    "Could not delete share" : "Klarte ikke å slette deling",
    "Please specify a file or folder path" : "Vennligst angi sti til en fil eller mappe",
    "Wrong path, file/folder doesn't exist" : "Feil sti, fil/mappe finnest ikke",
    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato, datoformatet må være ÅÅÅÅ-MM-DD",
    "Please specify a valid user" : "Vennligst angi en gyldig bruker",
    "Group sharing is disabled by the administrator" : "Gruppedeling er deaktivert av administratoren",
    "Please specify a valid group" : "Vennligst angi en gyldig gruppe",
    "The group is blacklisted for sharing" : "Gruppen er svartelistet for deling",
    "Public link sharing is disabled by the administrator" : "Deling med offentlig lenke er deaktivert av administratoren",
    "Public upload disabled by the administrator" : "Deling med offentlig opplasting er deaktivert av administratoren",
    "Public upload is only possible for publicly shared folders" : "Offentlig opplasting er kun mulig for offentlig delte mapper",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Deling av %s feilet, fordi serveren ikke tillater delinger fra type %s",
    "Unknown share type" : "Ukjent delingstype",
    "Could not lock path" : "Klarte ikke å låse stien",
    "Not a directory" : "Ikke en katalog",
    "Can't change permissions for public share links" : "Kan ikke endre rettigheter for offentlig delte lenker",
    "Only recipient can change accepted state" : "Kun mottaker kan endre akseptert tilstand",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "\"%1$s\" delte \"%3$s\" med deg (på vegne av \"%2$s\")",
    "\"%1$s\" shared \"%3$s\" with you" : "\"%1$s\" delte \"%3$s\" med deg",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "\"%1$s\" har invitert deg til å se \"%3$s\" (på vegne av \"%2$s\")",
    "\"%1$s\" invited you to view \"%3$s\"" : "\"%1$s\" har invitert deg til å se \"%3$s\"",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "Automatically accept new incoming local user shares" : "Godta nye innkommende lokale brukerdelinger automatisk",
    "This share is password-protected" : "Denne delingen er passordbeskyttet",
    "The password is wrong. Try again." : "Passordet er feil. Prøv på nytt.",
    "Password" : "Passord",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Name" : "Navn",
    "State" : "Status",
    "Share time" : "Delingstidspunkt",
    "Expiration date" : "Utløpsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Beklager, denne lenken ser ikke ut til å virke lenger.",
    "Reasons might be:" : "Mulige årsaker:",
    "the item was removed" : "elementet er fjernet",
    "the link expired" : "lenken er utløpt",
    "sharing is disabled" : "deling er deaktivert",
    "For more info, please ask the person who sent this link." : "For mer informasjon, spør personen som sendte lenken.",
    "%s is publicly shared" : "%s er offentlig delt",
    "Download" : "Last ned",
    "Download %s" : "Last ned %s",
    "Direct link" : "Direkte lenke",
    "Group Sharing Blacklist" : "Gruppedeling Blokkeringsliste",
    "Exclude groups from receiving shares" : "Ekskluder grupper fra å motta delinger"
},
"nplurals=2; plural=(n != 1);");
